example="client"
--example="server"

local losc = require"losc"
local plugin = require"losc.plugins.udp-socket"
local Packet = require"losc.packet"

if example=="client" then
	-----------------
	-- Simple client.
	-- Uses the udp-socket plugin.
	local udp = plugin.new {sendAddr = "localhost", sendPort = 9000}
	local osc = losc.new {plugin = udp}

	local message = losc.new_message {
		address = "/foo/bar",
		types = "ifsb",
		123, 1.2345, "hi", "blobdata",
	}

	osc:send(message)

	stage:addEventListener(Event.KEY_DOWN, function(e)
		if e.keyCode == KeyCode.M then
			osc:send(message)
		end
	end)
end


if example=="server" then
	-----------------
	-- Simple server.
	-- Uses the udp-socket plugin.
	local udp = plugin.new {
		recvAddr = "localhost",
		recvPort = 9000,
		ignore_late = true, -- ignore late bundles
		non_blocking = true, -- do not block on :open(), :poll() handles processing
	}
	local osc = losc.new {plugin = udp}

	local function print_data(data)
		local msg = data.message
		print("address: " .. msg.address, "timestamp: " .. data.timestamp)
		for index, argument in ipairs(msg) do
			print("index: " .. index, "arg: " .. argument)
		end
	end
	local function print_message(msg)
		local text = TextField.new(nil, msg.address)
		stage:addChild(text)
		text:setPosition(math.random(400), math.random(400))
		print("address: " .. msg.address, "time: "..plugin:now():timestamp(plugin.precision))
		for index, argument in ipairs(msg) do
			print("index: " .. index, "arg: " .. argument)
		end
	end

	osc:add_handler("/foo/bar", function(data)
		print_data(data)
	end)
	osc:add_handler("/foo/bar2", function(data)
		print_data(data)
	end)

	osc:open() -- non blocking call :)
	isopened=true

	function onEnterFrame()
		local status, data = osc:poll()
		if status and data then
			local message = Packet.unpack(data)
			print_message(message)
		end
	end
	stage:addEventListener(Event.ENTER_FRAME, onEnterFrame)

	stage:addEventListener(Event.KEY_DOWN, function(e)
		if e.keyCode == KeyCode.S then
			if not isopened then
				print("server opened")
				osc:open()
				isopened = true
			end
		elseif e.keyCode == KeyCode.P then
			if isopened then
				print("server closed")
				isopened = false
				osc:close()
			end
		end
	end)
end
